@@ -1,19 +1,22 @@
 #!/usr/bin/python3
-import apt
 import gettext
-import gi
+import locale
 import os
 import platform
 import subprocess
-import locale
+
+import apt
+import gi
+
 gi.require_version("Gtk", "3.0")
-from gi.repository import Gtk, Gio
+from gi.repository import Gtk
 
 NORUN_FLAG = os.path.expanduser("~/.linuxmint/mintwelcome/norun.flag")
 
 # i18n
 gettext.install("mintwelcome", "/usr/share/linuxmint/locale")
 from locale import gettext as _
+
 locale.bindtextdomain("mintwelcome", "/usr/share/linuxmint/locale")
 locale.textdomain("mintwelcome")
 
@@ -33,6 +36,7 @@ class SidebarRow(Gtk.ListBoxRow):
         box.pack_start(label, False, False, 0)
         self.add(box)
 
+
 class MintWelcome():
 
     def __init__(self):
@@ -54,7 +58,7 @@ class MintWelcome():
         release_notes = config['RELEASE_NOTES_URL']
         new_features = config['NEW_FEATURES_URL']
         architecture = "64-bit"
-        if platform.machine() != "x86_64":
+        if platform.machine() not in ["x86_64", "aarch64"]:
             architecture = "32-bit"
 
         # distro-specific
